@@ -18,11 +18,11 @@ sub new {
     my $class = shift;
     my %p = @_;
     return bless {
-		  query           => $p{cgi} || CGI->new,
-		  headers_out     => HTML::Mason::FakeTable->new,
-		  err_headers_out => HTML::Mason::FakeTable->new,
-		  pnotes          => {},
-		 }, $class;
+                  query           => $p{cgi} || CGI->new,
+                  headers_out     => HTML::Mason::FakeTable->new,
+                  err_headers_out => HTML::Mason::FakeTable->new,
+                  pnotes          => {},
+                 }, $class;
 }
 
 # CGI request are _always_ main, and there is never a previous or a next
@@ -160,9 +160,15 @@ sub http_header {
 }
 
 sub send_http_header {
-    print shift->http_header;
+    my $self = shift;
+
+    print STDOUT $self->http_header;
+
+    $self->{http_header_sent} = 1;
 }
 
+sub http_header_sent { shift->{http_header_sent} }
+
 # How do we know this under CGI?
 # sub get_basic_auth_pw {}
 # sub note_basic_auth_failure {}
@@ -260,14 +266,14 @@ sub no_cache {
 }
 
 sub print {
-    shift->query->print(@_);
+    print @_;
 }
 
 sub send_fd {
     my ($self, $fd) = @_;
     local $_;
-    my $p = $self->query->can('print');
-    $p->($_) while defined ($_ = <$fd>);
+
+    print STDOUT while defined ($_ = <$fd>);
 }
 
 # Should this perhaps throw an exception?
