@@ -51,6 +51,7 @@ use constant STACK_PATH         => 4;
 use constant STACK_DEPTH        => 5;
 use constant STACK_BASE_COMP    => 6;
 use constant STACK_IN_CALL_SELF => 7;
+use constant STACK_BUFFER_IS_FLUSHABLE => 8;
 
 # HTML::Mason::Exceptions always exports rethrow_exception() and isa_mason_exception()
 use HTML::Mason::Exceptions( abbr => [qw(error param_error syntax_error
@@ -1157,6 +1158,8 @@ sub print
 {
     my $self = shift;
 
+    # $self->{top_stack} is always defined _except_ in the case of a
+    # call to print inside a start-/end-request plugin.
     my $bufref =
         ( defined $self->{top_stack}
           ? $self->{top_stack}->[STACK_BUFFER]
@@ -1211,18 +1214,20 @@ sub comp {
     my $filter_buffer = '';
     my $top_buffer = defined($mods{store}) ? $mods{store} : $top_stack->[STACK_BUFFER];
     my $stack_buffer = $comp->{has_filter} ? \$filter_buffer : $top_buffer;
+    my $flushable = exists $mods{flushable} ? $mods{flushable} : 1;
 
     # Add new stack frame and point dynamically scoped $self->{top_stack} at it.
     local $self->{top_stack} = $self->{stack}->[$depth-1] =
         [
-         $comp,          # STACK_COMP
-         \@_,            # STACK_ARGS
-         $stack_buffer,  # STACK_BUFFER
-         \%mods,         # STACK_MODS
-         $path,          # STACK_PATH
-         $depth,         # STACK_DEPTH
-         undef,          # STACK_BASE_COMP
-         undef,          # STACK_IN_CALL_SELF
+         $comp,           # STACK_COMP
+         \@_,             # STACK_ARGS
+         $stack_buffer,   # STACK_BUFFER
+         \%mods,          # STACK_MODS
+         $path,           # STACK_PATH
+         $depth,          # STACK_DEPTH
+         undef,           # STACK_BASE_COMP
+         undef,           # STACK_IN_CALL_SELF
+         $flushable       # STACK_BUFFER_IS_FLUSHABLE
          ];
 
     # Run start_component hooks for each plugin.
@@ -1291,7 +1296,7 @@ sub comp {
 sub scomp {
     my $self = shift;
     my $buf;
-    $self->comp({store=>\$buf},@_);
+    $self->comp({store => \$buf, flushable => 0},@_);
     return $buf;
 }
 
@@ -1312,6 +1317,7 @@ sub content {
     my $save_frame = $self->{top_stack};
     { local $self->{top_stack} = $self->{stack}->[$self->{top_stack}->[STACK_DEPTH]-2];
       local $self->{top_stack}->[STACK_BUFFER] = \$buffer;
+      local $self->{top_stack}->[STACK_BUFFER_IS_FLUSHABLE] = 0;
       $content->(); }
     $self->{top_stack} = $save_frame;
 
@@ -1344,8 +1350,26 @@ sub flush_buffer
 {
     my $self = shift;
 
-    $self->out_method->($self->{request_buffer});
+    $self->out_method->($self->{request_buffer})
+        if length $self->{request_buffer};
     $self->{request_buffer} = '';
+
+    if ( $self->{top_stack}->[STACK_BUFFER_IS_FLUSHABLE]
+         && $self->{top_stack}->[STACK_BUFFER] )
+    {
+        my $comp = $self->{top_stack}->[STACK_COMP];
+        if ( $comp->has_filter()
+             && defined $comp->filter() )
+        {
+            $self->out_method->
+                ( $comp->filter->( ${ $self->{top_stack}->[STACK_BUFFER] } ) );
+        }
+        else
+        {
+            $self->out_method->( ${ $self->{top_stack}->[STACK_BUFFER] } );
+        }
+        ${$self->{top_stack}->[STACK_BUFFER]} = '';
+    }
 }
 
 sub request_args
